#' @title Scanning Information for HCP Data
#'
#' @description A \code{data.frame} with all the available scanning information
#' for the HCP data.
#'
"hcp_scanning_info"

#' @title Scanning Information for HCP 900 Data
#'
#' @description A \code{data.frame} with all the available scanning information
#' for the HCP 900 data.
#'
"hcp_900_scanning_info"

#' @title Scanning Information for HCP 1200 Data
#'
#' @description A \code{data.frame} with all the available scanning information
#' for the HCP 1200 data.
#'
"hcp_1200_scanning_info"
